@@ -57,7 +57,7 @@ class Tethys(object):
 
         """
         setattr(self, 'datasets', [])
-        setattr(self, '_datasets_sites', {})
+        setattr(self, '_datasets_stations', {})
         setattr(self, '_dataset_key', dataset_key)
 
         if isinstance(remotes_list, list):
@@ -94,51 +94,51 @@ class Tethys(object):
 
             ds_dict = {d['dataset_id']: {'dataset': d, 'remote': remote} for d in ds_list}
 
-            self._datasets_sites.update(ds_dict)
+            self._datasets_stations.update(ds_dict)
 
         except:
             print('No datasets.json file in S3 bucket')
 
 
-    def get_sites_list(self, dataset_id):
+    def get_stations_list(self, dataset_id):
         """
 
         """
-        # dataset = self._datasets_sites[dataset_id]
-        # if not hasattr(self, '_datasets_sites'):
+        # dataset = self._datasets_stations[dataset_id]
+        # if not hasattr(self, '_datasets_stations'):
 
-        remote = self._datasets_sites[dataset_id]['remote']
+        remote = self._datasets_stations[dataset_id]['remote']
 
         s3 = s3_connection(remote['connection_config'])
 
-        site_key = key_patterns['site'].format(dataset_id=dataset_id)
+        station_key = key_patterns['station'].format(dataset_id=dataset_id)
 
         try:
-            site_resp = s3.get_object(Key=site_key, Bucket=remote['bucket'])
+            station_resp = s3.get_object(Key=station_key, Bucket=remote['bucket'])
 
-            site_obj = site_resp.pop('Body')
-            site_list = orjson.loads(read_pkl_zstd(site_obj.read(), False))
+            station_obj = station_resp.pop('Body')
+            station_list = orjson.loads(read_pkl_zstd(station_obj.read(), False))
 
-            self._datasets_sites[dataset_id].update({'sites': {s['site_id']: s for s in site_list}})
+            self._datasets_stations[dataset_id].update({'stations': {s['station_id']: s for s in station_list}})
 
             ## Create spatial index here
 
-            return site_list
+            return station_list
 
         except:
-            print('No sites.json.zst file in S3 bucket')
+            print('No stations.json.zst file in S3 bucket')
 
 
-    def get_time_series_results(self, dataset_id, site_id, from_date=None, to_date=None, quality_codes=False, output='DataArray'):
+    def get_time_series_results(self, dataset_id, station_id, from_date=None, to_date=None, quality_codes=False, output='DataArray'):
         """
-        Function to query the time series data given a specific dataset_id and site_id. Multiple optional outputs.
+        Function to query the time series data given a specific dataset_id and station_id. Multiple optional outputs.
 
         Parameters
         ----------
         dataset_id : str
             The hashed str of the dataset_id.
-        site_id : str
-            The hashed string of the site_id.
+        station_id : str
+            The hashed string of the station_id.
         from_date : str, Timestamp, datetime, or None
             The start date of the selection.
         to_date : str, Timestamp, datetime, or None
@@ -156,12 +156,12 @@ class Tethys(object):
         -------
         Whatever the output was set to.
         """
-        dataset_dict = self._datasets_sites[dataset_id]
-        dataset_site = dataset_dict['sites'][site_id]
+        dataset_dict = self._datasets_stations[dataset_id]
+        dataset_station = dataset_dict['stations'][station_id]
         dataset = dataset_dict['dataset']
         parameter = dataset['parameter']
 
-        obj_info = dataset_site['time_series_object_info']
+        obj_info = dataset_station['time_series_object_info']
         ts_key = obj_info['key']
         bucket = obj_info['bucket']
 
@@ -211,19 +211,19 @@ class Tethys(object):
                 raise ValueError("output must be one of 'Dataset', 'DataArray', 'Dict', or 'json'")
 
         except:
-            print('No time series data for dataset_id/site_id combo')
+            print('No time series data for dataset_id/station_id combo')
 
 
-    # def bulk_time_series_results(self, dataset_id, site_ids, from_date=None, to_date=None, quality_codes=False, output='DataArray'):
+    # def bulk_time_series_results(self, dataset_id, station_ids, from_date=None, to_date=None, quality_codes=False, output='DataArray'):
     #     """
-    #     Function to bulk query the time series data given a specific dataset_id and a list of site_ids. Multiple optional outputs.
+    #     Function to bulk query the time series data given a specific dataset_id and a list of station_ids. Multiple optional outputs.
     #
     #     Parameters
     #     ----------
     #     dataset_id : str
     #         The hashed str of the dataset_id.
-    #     site_ids : list of str
-    #         A list of hashed strings of the site_ids.
+    #     station_ids : list of str
+    #         A list of hashed strings of the station_ids.
     #     from_date : str, Timestamp, datetime, or None
     #         The start date of the selection.
     #     to_date : str, Timestamp, datetime, or None
@@ -241,7 +241,7 @@ class Tethys(object):
     #     -------
     #     Whatever the output was set to.
     #     """
-    #     lister = [(dataset_id, s, from_date, to_date, quality_codes, 'Dataset') for s in site_ids]
+    #     lister = [(dataset_id, s, from_date, to_date, quality_codes, 'Dataset') for s in station_ids]
     #
     #     output = ThreadPool(4).starmap(self.get_time_series_results, lister)
     #
@@ -261,19 +261,19 @@ class Tethys(object):
 # remote = remotes_list[0]
 #
 # dataset_id = 'cbba7575fb51024f4bf961e2'
-# site_id = 'b7c99b99c209c70a946472fd'
-# site_ids = ['b7c99b99c209c70a946472fd', '76cf3a75b64396ed21af3cb5']
+# station_id = 'b7c99b99c209c70a946472fd'
+# station_ids = ['b7c99b99c209c70a946472fd', '76cf3a75b64396ed21af3cb5']
 #
 # dataset_id = '9e1a03dc379cbf7037b0873d'
-# site_id = '5c3848a5b9acee6694714e7e'
+# station_id = '5c3848a5b9acee6694714e7e'
 #
 # self = Tethys()
 # self = Tethys(remotes_list)
 #
-# site_list1 = self.get_sites_list(dataset_id)
+# station_list1 = self.get_stations_list(dataset_id)
 #
-# data1 = self.get_time_series_results(dataset_id, site_id, output='Dataset')
-# data1 = self.get_time_series_results(dataset_id, site_id, output='Dict')
-# data1 = self.get_time_series_results(dataset_id, site_id, from_date='2012-01-02 00:00', output='Dataset')
+# data1 = self.get_time_series_results(dataset_id, station_id, output='Dataset')
+# data1 = self.get_time_series_results(dataset_id, station_id, output='Dict')
+# data1 = self.get_time_series_results(dataset_id, station_id, from_date='2012-01-02 00:00', output='Dataset')
 
-# data2 = self.bulk_time_series_results(dataset_id, site_ids, output='DataArray')
+# data2 = self.bulk_time_series_results(dataset_id, station_ids, output='DataArray')
